@@ -1,6 +1,6 @@
-baseoai <- function() "http://ws.pangaea.de/oai/"
+baseoai <- function() "http://ws.pangaea.de/oai/provider"
 base <- function() 'https://doi.pangaea.de/'
-sbase <- function() "https://www.pangaea.de/search"
+sbase <- function() "https://www.pangaea.de/advanced/search.php"
 
 pgc <- function(x) Filter(Negate(is.null), x)
 
@@ -13,34 +13,37 @@ pluck <- function(x, name, type) {
 }
 
 check <- function(x){
-  if(is.character(x)){
-    if( grepl("does not exist|unknown", x))
+  if (is.character(x)) {
+    if ( grepl("does not exist|unknown", x))
       stop(x, call. = FALSE)
   }
 }
 
 read_csv <- function(x){
-  lns <- readLines(x, n = 300)
+  lns <- readLines(x, n = 1000)
   ln_no <- grep("\\*/", lns)
-  tmp <- read.csv(x, header = FALSE, sep = "\t", skip = ln_no+1, stringsAsFactors=FALSE)
-  nn <- strsplit(lns[ln_no+1], "\t")[[1]]
+  tmp <- read.csv(x, header = FALSE, sep = "\t",
+                  skip = ln_no + 1, stringsAsFactors = FALSE)
+  nn <- strsplit(lns[ln_no + 1], "\t")[[1]]
   setNames(tmp, nn)
 }
 
-ifn <- function(x) if(is.null(x)) NA else x
+ifn <- function(x) if (is.null(x)) NA else x
 
 strextract <- function(str, pattern) regmatches(str, regexpr(pattern, str))
 
 capwords <- function(s, strict = FALSE, onlyfirst = FALSE) {
   cap <- function(s) paste(toupper(substring(s,1,1)), {
-    s <- substring(s,2); if(strict) tolower(s) else s
+    s <- substring(s,2); if (strict) tolower(s) else s
   }, sep = "", collapse = " " )
-  if(!onlyfirst){
+  if (!onlyfirst) {
     sapply(strsplit(s, split = " "), cap, USE.NAMES = !is.null(names(s)))
   } else {
     sapply(s, function(x)
       paste(toupper(substring(x,1,1)),
             tolower(substring(x,2)),
-            sep="", collapse=" "), USE.NAMES=F)
+            sep = "", collapse = " "), USE.NAMES = FALSE)
   }
 }
+
+cuf8 <- function(x) httr::content(x, "text", encoding = "UTF-8")
